==> haskell-text-builder-dev-0.3.3.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-LpbMCLmFBDfEHpvxS3m1BI
key:                  text-builder-dev-0.3.3.2-LpbMCLmFBDfEHpvxS3m1BI
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  10fa15e605d52e8cb066594464364d4f
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-LpbMCLmFBDfEHpvxS3m1BI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-H8H8pYK4wZ4B6gQp29GKja
    isomorphism-class-0.1.1-DdUJHz89W7JFY6AvwmPAwL
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-dev-0.3.3.2-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-G9GJ4AqT8EqHVzecuU8z7o
key:                  text-builder-dev-0.3.3.2-G9GJ4AqT8EqHVzecuU8z7o
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  39413e825472452c047146ad46f03f81
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-G9GJ4AqT8EqHVzecuU8z7o
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-H2irnCZX1aA5kAAznOOMGK
    isomorphism-class-0.1.1-tEFtMOfQd6rtA3oz9ZtV
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
